@@ -47,7 +47,7 @@ class Exceptions:
 
 class OutpostsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -56,8 +56,8 @@ class OutpostsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_outpost(
@@ -70,20 +70,20 @@ class OutpostsClient:
         Tags: Dict[str, str] = None,
     ) -> CreateOutpostOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.create_outpost)
-        [Show boto3-stubs documentation](./client.md#create-outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.create_outpost)
+        [Show boto3-stubs documentation](./client.md#create_outpost)
         """
 
     def delete_outpost(self, OutpostId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.delete_outpost)
-        [Show boto3-stubs documentation](./client.md#delete-outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        [Show boto3-stubs documentation](./client.md#delete_outpost)
         """
 
     def delete_site(self, SiteId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.delete_site)
-        [Show boto3-stubs documentation](./client.md#delete-site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.delete_site)
+        [Show boto3-stubs documentation](./client.md#delete_site)
         """
 
     def generate_presigned_url(
@@ -94,52 +94,52 @@ class OutpostsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_outpost(self, OutpostId: str) -> GetOutpostOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.get_outpost)
-        [Show boto3-stubs documentation](./client.md#get-outpost)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.get_outpost)
+        [Show boto3-stubs documentation](./client.md#get_outpost)
         """
 
     def get_outpost_instance_types(
         self, OutpostId: str, NextToken: str = None, MaxResults: int = None
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
-        [Show boto3-stubs documentation](./client.md#get-outpost-instance-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        [Show boto3-stubs documentation](./client.md#get_outpost_instance_types)
         """
 
     def list_outposts(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListOutpostsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.list_outposts)
-        [Show boto3-stubs documentation](./client.md#list-outposts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.list_outposts)
+        [Show boto3-stubs documentation](./client.md#list_outposts)
         """
 
     def list_sites(self, NextToken: str = None, MaxResults: int = None) -> ListSitesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.list_sites)
-        [Show boto3-stubs documentation](./client.md#list-sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.list_sites)
+        [Show boto3-stubs documentation](./client.md#list_sites)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/outposts.html#Outposts.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/outposts.html#Outposts.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
